from distutils.core import setup

setup(
    name='pythonsample',
    version='0.1', 
    description = 'samplpe python',
    author = 'Neethi',             
    author_email = 'vinoth.royal6@gmail.com')
